/*
The software in this package is distributed under the GNU General
Public License version 2 (with a special exception described below).

A copy of GNU General Public License (GPL) is included in this distribution,
in the file COPYING.GPL.

As a special exception, if other files instantiate templates or use macros
or inline functions from this file, or you compile this file and link it
with other works to produce a work based on this file, this file
does not by itself cause the resulting work to be covered
by the GNU General Public License.

However the source code for this file must still be made available
in accordance with section (3) of the GNU General Public License.

This exception does not invalidate any other reasons why a work based
on this file might be covered by the GNU General Public License.
*/
/**
   tests for the module "crypto"

   @copyright Intra2net AG
*/
#define BOOST_TEST_DYN_LINK
#include <boost/test/unit_test.hpp>
#include <vector>
#include <tmpfstream.hpp>
#include <iostream>
#include <fstream>
#include <string>

#include "crypto.hxx"

using namespace std;
using namespace I2n;


class TestCryptoFixture
{
protected:

    string Filename;

    tmpfstream Tempfile;

    void write_tempfile()
    {
        string tmpfile_name = "/tmp/libi2ncommon_test_crypto_XXXXXX";
        Tempfile.open(tmpfile_name);
        Tempfile << "Long Data and or Password";
        Tempfile.close();

        Filename = Tempfile.get_tmp_filename();
    }

public:
    TestCryptoFixture()
    {
        write_tempfile();
    }

    ~TestCryptoFixture()
    {
        Tempfile.unlink();
    }
};

BOOST_FIXTURE_TEST_SUITE(Crypto, TestCryptoFixture)

BOOST_AUTO_TEST_CASE(CheckHashMD5)
{
    const string hash = hash_data("Long Data and or Password",
                                  MD5);
    BOOST_CHECK_EQUAL(hash, string("E5952C81BBD04F9CB748433B9431F674"));
}

BOOST_AUTO_TEST_CASE(CheckHashSHA1)
{
    const string hash = hash_data("Long Data and or Password",
                                  SHA1);
    BOOST_CHECK_EQUAL(hash, string("5935A22DAA087672FE2EA0E4485D58BC77E6068D"));
}

BOOST_AUTO_TEST_CASE(CheckHashSHA256)
{
    const string hash = hash_data("Long Data and or Password",
                                  SHA256);
    BOOST_CHECK_EQUAL(hash, string("6D7F287A7E01ADF1A66C19D61C8D5A3BD68C1F"
                                   "10565A6D37A5920B09152D62CE"));
}

BOOST_AUTO_TEST_CASE(CheckHashSHA384)
{
    const string hash = hash_data("Long Data and or Password",
                                  SHA384);
    BOOST_CHECK_EQUAL(hash, string("1D879CCDFF4E50C32318A1F0FB8AF8A0B"
                                   "150432CECAF41E5C7C0C75688E1F776"
                                   "14CA70407A9BC97FDD1CEC4CF291B66B"));
}

BOOST_AUTO_TEST_CASE(CheckHashSHA512)
{
    const string hash = hash_file(Filename,
                                  SHA512);
    BOOST_CHECK_EQUAL(hash, string("CBD561B4D1E13C08672CBCCAC855FAC3F4"
                                   "7672548D0B61B0BB201017E4D93B239E"
                                   "969DB3588F1466F34FB27A7D0AEFE203"
                                   "594808E16659BEDD4B25F34EC46CDB"));
}

BOOST_AUTO_TEST_CASE(CheckHashFileMD5)
{
    const string hash = hash_file(Filename,
                                  MD5);
    BOOST_CHECK_EQUAL(hash, string("E5952C81BBD04F9CB748433B9431F674"));
}

BOOST_AUTO_TEST_CASE(CheckHashFileSHA1)
{
    const string hash = hash_file(Filename,
                                  SHA1);
    BOOST_CHECK_EQUAL(hash, string("5935A22DAA087672FE2EA0E4485D58BC77E6068D"));
}

BOOST_AUTO_TEST_CASE(CheckHashFileSHA256)
{
    const string hash = hash_file(Filename,
                                  SHA256);
    BOOST_CHECK_EQUAL(hash, string("6D7F287A7E01ADF1A66C19D61C8D5A3BD68C1F"
                                   "10565A6D37A5920B09152D62CE"));
}

BOOST_AUTO_TEST_CASE(CheckHashFileSHA384)
{
    const string hash = hash_file(Filename,
                                  SHA384);
    BOOST_CHECK_EQUAL(hash, string("1D879CCDFF4E50C32318A1F0FB8AF8A0B"
                                   "150432CECAF41E5C7C0C75688E1F776"
                                   "14CA70407A9BC97FDD1CEC4CF291B66B"));
}

BOOST_AUTO_TEST_CASE(CheckHashFileSHA512)
{
    const string hash = hash_file(Filename,
                                  SHA512);
    BOOST_CHECK_EQUAL(hash, string("CBD561B4D1E13C08672CBCCAC855FAC3F4"
                                   "7672548D0B61B0BB201017E4D93B239E"
                                   "969DB3588F1466F34FB27A7D0AEFE203"
                                   "594808E16659BEDD4B25F34EC46CDB"));
}

BOOST_AUTO_TEST_SUITE_END()
